@@ -11,6 +11,8 @@ use std::process::Command;
 fn main() {
   let out_dir = env::var("OUT_DIR").unwrap();
 
+  println!("cargo:rustc-link-search=native={}", out_dir);
+
   #[cfg(feature="bootable")]
   build_device_boot(&out_dir);
 }
@@ -23,15 +25,13 @@ fn build_device_boot(out_dir: &String) {
       "-mmcu=avrxmega3", "-a",
       "-o"])
     .arg(&format!("{}/oxide-boot-atmega4809.o", out_dir))
-    .output().expect("Assembly failed");
+    .output().expect("Boot Assembly failed");
 
   let _result = Command::new("avr-ar")
     .args(&["crus", "liboxide-boot-atmega4809.a", "oxide-boot-atmega4809.o"])
     .current_dir(&Path::new(out_dir))
-    .output().expect("Packaging library failed");
+    .output().expect("Packaging boot library failed");
 
-
-  println!("cargo:rustc-link-search=native={}", out_dir);
   println!("cargo:rustc-link-lib=static=oxide-boot-atmega4809");
   println!("cargo:rerun-if-changed=src/hal/atmega4809/boot.S");
-}
+}
\ No newline at end of file
