@@ -45,6 +45,12 @@ pub mod nanoevery {
     pub d11: &'static mut atmega4809::port::porte::PinImpl,
     pub d12: &'static mut atmega4809::port::porte::PinImpl,
     pub d13: &'static mut atmega4809::port::porte::PinImpl,
+
+    pub watchdog: &'static mut atmega4809::watchdog::WatchdogImpl,
+
+    pub usb_serial: &'static mut atmega4809::serial::usart3::SerialImpl,
+    pub usb_serial_tx: &'static mut atmega4809::port::portb::PinImpl,
+    pub usb_serial_rx: &'static mut atmega4809::port::portb::PinImpl,
   }
 
 
@@ -77,7 +83,13 @@ pub mod nanoevery {
         d10: atmega4809::port::portb::pin_instance(1),
         d11: atmega4809::port::porte::pin_instance(0),
         d12: atmega4809::port::porte::pin_instance(1),
-        d13: atmega4809::port::porte::pin_instance(2)
+        d13: atmega4809::port::porte::pin_instance(2),
+
+        watchdog: avr.watchdog,
+
+        usb_serial: avr.usart3.mux(atmega4809::serial::usart3::SerialPortPins::PortB54),
+        usb_serial_tx: atmega4809::port::portb::pin_instance(4),
+        usb_serial_rx: atmega4809::port::portb::pin_instance(5),
       }
     }
   }
