@@ -27,18 +27,23 @@ pub mod memory {
   pub const USER_SIZE   : usize  =     64;
 }
 
+#[cfg(feature = "atmega4809")]
+pub mod oxide {
+  pub const MAX_THREADS : usize  = 1;
+}
+
 #[cfg(feature="20MHz")]
 pub mod clock {
   pub const MASTER_CLOCK_HZ: u32         = 20_000_000; // Config'd in device fuses
-  pub const MASTER_CLOCK_PRESCALER:  u8  = 6;          // Device default (per datasheet)
-  pub const MASTER_TICK_FREQ_HZ: u32     = 954;        // Desired frequency of master clock
+  pub const MASTER_CLOCK_PRESCALER:  u8  = 10;         // We configure this on boot
+  pub const MASTER_TICK_FREQ_HZ: u16     = 500;        // Desired frequency of master clock
 }
 
 #[cfg(feature="16MHz")]
 pub mod clock {
   pub const MASTER_CLOCK_HZ: u32         = 16_000_000; // Config'd in device fuses
-  pub const MASTER_CLOCK_PRESCALER:  u8  = 6;          // Device default (per datasheet)
-  pub const MASTER_TICK_FREQ_HZ: u32     = 924;        // Desired frequency of master clock
+  pub const MASTER_CLOCK_PRESCALER:  u8  = 8;         // we configure this on boot
+  pub const MASTER_TICK_FREQ_HZ: u16     = 500;        // Desired frequency of master clock
 }
 
 
