@@ -15,31 +15,31 @@
 pub mod porta {
   use crate::{atmel_port_tpl};
 
-  atmel_port_tpl!(avr_device::atmega4809::PORTA::PTR, _ivr_porta_port);
+  atmel_port_tpl!(super::super::ADDR_PORTA, _ivr_porta_port);
 }
 pub mod portb {
   use crate::{atmel_port_tpl};
 
-  atmel_port_tpl!(avr_device::atmega4809::PORTB::PTR, _ivr_portb_port);
+  atmel_port_tpl!(super::super::ADDR_PORTB, _ivr_portb_port);
 }
 pub mod portc {
   use crate::{atmel_port_tpl};
 
-  atmel_port_tpl!(avr_device::atmega4809::PORTC::PTR, _ivr_portc_port);
+  atmel_port_tpl!(super::super::ADDR_PORTC, _ivr_portc_port);
 }
 pub mod portd {
   use crate::{atmel_port_tpl};
 
-  atmel_port_tpl!(avr_device::atmega4809::PORTD::PTR, _ivr_portd_port);
+  atmel_port_tpl!(super::super::ADDR_PORTD, _ivr_portd_port);
 }
 pub mod porte {
   use crate::{atmel_port_tpl};
 
-  atmel_port_tpl!(avr_device::atmega4809::PORTE::PTR, _ivr_porte_port);
+  atmel_port_tpl!(super::super::ADDR_PORTE, _ivr_porte_port);
 }
 
 pub mod portf {
   use crate::{atmel_port_tpl};
 
-  atmel_port_tpl!(avr_device::atmega4809::PORTF::PTR, _ivr_portf_port);
+  atmel_port_tpl!(super::super::ADDR_PORTF, _ivr_portf_port);
 }
\ No newline at end of file
