@@ -16,24 +16,24 @@
 pub mod tcb0 {
   use crate::atmel_tcb;
 
-  atmel_tcb!(avr_device::atmega4809::TCB0::PTR, _ivr_tcb0_int);
+  atmel_tcb!(super::super::ADDR_TCB0, _ivr_tcb0_int);
 }
 
 pub mod tcb1 {
   use crate::atmel_tcb;
-  atmel_tcb!(avr_device::atmega4809::TCB1::PTR, _ivr_tcb1_int);
+  atmel_tcb!(super::super::ADDR_TCB1, _ivr_tcb1_int);
 }
 
 pub mod tcb2 {
   use crate::atmel_tcb;
 
-  atmel_tcb!(avr_device::atmega4809::TCB2::PTR, _ivr_tcb2_int);
+  atmel_tcb!(super::super::ADDR_TCB2, _ivr_tcb2_int);
 }
 
 pub mod tcb3 {
   use crate::atmel_tcb;
 
-  atmel_tcb!(avr_device::atmega4809::TCB3::PTR, _ivr_tcb3_int);
+  atmel_tcb!(super::super::ADDR_TCB3, _ivr_tcb3_int);
 }
 
 
