@@ -9,6 +9,9 @@
 pub mod timer;
 pub mod port;
 pub mod debugled;
+pub mod watchdog;
+pub mod cpu;
+pub mod serial;
 
 
 #[allow(unused_assignments)]
@@ -25,9 +28,10 @@ pub(in crate) fn busy_loop(mut c: u16) {
 }
 
 #[cfg(not(target_arch="avr"))]
-pub(in crate) fn busy_loop(mut c: u16) {
+#[allow(dead_code)]
+pub(in crate) fn busy_loop(c: u16) {
   let mut count = 0u16;
-  let mut volatile = &mut count as *mut u16;
+  let volatile = &mut count as *mut u16;
 
   for _i in 0..c {
     unsafe {
@@ -41,3 +45,16 @@ pub(in crate) fn busy_loop(mut c: u16) {
 #[cfg(target_arch="avr")]
 pub unsafe extern "C" fn rust_eh_personality() -> () {
 }
+
+#[macro_export]
+macro_rules! v_write {
+  ($type:ty, $ref:expr, $val:expr) => {
+    core::ptr::write_volatile(&mut $ref as *mut $type, $val)
+  }
+}
+#[macro_export]
+macro_rules! v_read {
+  ($type:ty, $ref:expr) => {
+    core::ptr::read_volatile(&$ref as *const $type)
+  }
+}
