@@ -8,6 +8,7 @@
 // Imports ===================================================================
 
 
+
 // Declarations ==============================================================
 /**
  * Input/output mode for a pin
@@ -88,6 +89,7 @@ where
 }
 
 // Code ======================================================================
+#[cfg(target_arch="avr")]
 pub mod base {
   use crate::hal::generic::port::InterruptMode;
 
@@ -250,7 +252,7 @@ pub mod base {
   #[macro_export]
   macro_rules! atmel_port_tpl {
     ($ref:expr, $isr:ident) => {
-      extern crate avr_device_snowgoons as avr_device;
+
 
       use crate::hal::generic::port::{PinMode,Pin,InterruptMode,PinInterruptHandler};
       use crate::hal::generic::port::base::{AtmelPortControl,AvrPortRegisterBlock};
@@ -324,7 +326,7 @@ pub mod base {
           instance().set_interrupt_mode(self.n, mode)
         }
         fn listen(&mut self, handler: Option<PinInterruptHandler>){
-          crate::hal::concurrency::imp::atomic(|_|{
+          crate::hal::concurrency::interrupt::isolated(||{
             unsafe {
               PINS[self.n as usize].handler = match handler {
                 Some(handler) => handler,
@@ -394,17 +396,272 @@ pub mod base {
        */
       #[no_mangle]
       pub unsafe extern "avr-interrupt" fn $isr() {
-        let intflags:u8 = core::ptr::read_volatile(&instance().intflags as *const u8);
-        let state:u8    = core::ptr::read_volatile(&instance().inp as *const u8);
-        let mut mask    = 0x01;
+        crate::hal::concurrency::interrupt::isr(||{
+          let intflags:u8 = core::ptr::read_volatile(&instance().intflags as *const u8);
+          let state:u8    = core::ptr::read_volatile(&instance().inp as *const u8);
+          let mut mask    = 0x01;
 
-        for pin in 0..=7 {
-          if (intflags & mask) > 0 {
-            (PINS[pin].handler)((state & mask) > 0);
+          for pin in 0..=7 {
+            if (intflags & mask) > 0 {
+              (PINS[pin].handler)((state & mask) > 0);
+            }
+            mask <<= 1;
+          }
+          instance().clear_interrupts();
+        })
+      }
+    }
+  }
+}
+
+#[cfg(not(target_arch="avr"))]
+pub mod base {
+  use crate::hal::generic::port::InterruptMode;
+
+  pub trait AtmelPortControl {
+    /// Set this pin as an output.
+    fn enable_output(&mut self, p: u8);
+    /// Disable output on this pin
+    fn disable_output(&mut self, p: u8);
+    /// Enable internal pullup on this pin
+    fn enable_pullup(&mut self, p: u8);
+    /// Disable internal pullup on this pin
+    fn disable_pullup(&mut self, p: u8);
+    /// Set a pin's output state high
+    fn set_high(&mut self, p: u8);
+    /// Set a pin's output state low
+    fn set_low(&mut self, p: u8);
+    /// Toggle a pin's input state
+    fn toggle(&mut self, p: u8);
+    /// Get a pin's state
+    fn get(&self, p: u8) -> bool;
+    /// Set the mode for interrupt generation for a pin
+    fn set_interrupt_mode(&mut self, p: u8, mode: InterruptMode);
+    /// True iff the given pin has generated an interrupt
+    fn interrupted(&self, p: u8) -> bool;
+    /// Clear the interrupt flag for all pins on this port
+    fn clear_interrupts(&mut self);
+  }
+
+  /**
+   * The AVR port control register block.  The structure provided by the
+   * auto-generated avr-device crate is just horrible, so we use our own
+   * rendition.  This allows accessing pin control by index, and also avoids
+   * having different types for every port.
+   */
+  #[repr(C)]
+  pub struct DummyPortRegisterBlock {
+    pub(crate) pin: [bool; 8],
+    pub(crate) o_en: [bool; 8],
+    pub(crate) pu_en: [bool; 8]
+  }
+
+
+
+  impl AtmelPortControl for DummyPortRegisterBlock {
+    fn enable_output(&mut self, p: u8) {
+      println!("*** PORT: Enable output pin {}", p);
+      self.o_en[p as usize] = true;
+    }
+
+    fn disable_output(&mut self, p: u8) {
+      println!("*** PORT: Disable output pin {}", p);
+      self.o_en[p as usize] = false;
+    }
+
+    fn enable_pullup(&mut self, p: u8) {
+      println!("*** PORT: Enable pullup pin {}", p);
+      self.pu_en[p as usize] = true;
+    }
+
+    fn disable_pullup(&mut self, p: u8) {
+      println!("*** PORT: Disable pullup pin {}", p);
+      self.pu_en[p as usize] = false;
+    }
+
+    fn set_high(&mut self, p: u8) {
+      println!("*** PORT: Set HIGH pin {}", p);
+      self.pin[p as usize] = true;
+    }
+
+    fn set_low(&mut self, p: u8) {
+      println!("*** PORT: Set LOW pin {}", p);
+      self.pin[p as usize] = false;
+    }
+
+    fn toggle(&mut self, p: u8) {
+      let old = self.pin[p as usize];
+
+      println!("*** PORT: TOGGLE pin {} ({} => {})", p, old, !old);
+
+      self.pin[p as usize] = !old;
+    }
+
+    fn get(&self, p: u8) -> bool {
+      let val = self.pin[p as usize];
+      println!("*** PORT: GET pin {} ({})", p, val);
+      val
+    }
+
+    fn set_interrupt_mode(&mut self, p: u8, _mode: InterruptMode) {
+      println!("*** PORT: Set interrupt mode pin {}", p);
+    }
+
+    fn interrupted(&self, p: u8) -> bool {
+      println!("*** PORT: Get interrupt flag pin {}", p);
+      false
+    }
+
+    fn clear_interrupts(&mut self) {
+      println!("*** PORT: Clear all interrupts");
+    }
+
+
+  }
+
+  #[macro_export]
+  macro_rules! atmel_port_tpl {
+    ($ref:expr, $isr:ident) => {
+
+
+      use crate::hal::generic::port::{PinMode,Pin,InterruptMode,PinInterruptHandler};
+      use crate::hal::generic::port::base::{AtmelPortControl,DummyPortRegisterBlock};
+
+      pub type PortImpl = DummyPortRegisterBlock;
+      pub type PinImpl = AtmelPin;
+
+      /**
+       * A single pin instance.  This is just a wrapper for a reference to
+       * the pin number and a place to stash the callback function that will
+       * be called when we have an interrupt.
+       */
+      pub struct AtmelPin {
+        n: u8,
+        handler: PinInterruptHandler
+      }
+
+      /**
+       * A no-op function that is the default handler for the button
+            * interrupt callbacks.
+       */
+      fn nop_handler(_state: bool) -> () {
+      }
+
+      /**
+       * Implementation of the Pin API for our Atmel PINs.
+       */
+      impl Pin for AtmelPin {
+        #[inline(always)]
+        fn set_mode(&mut self, mode: PinMode) {
+          match mode {
+            PinMode::Output => {
+              instance().enable_output(self.n);
+            },
+            PinMode::InputPullup => {
+              instance().enable_pullup(self.n);
+              instance().disable_output(self.n);
+            },
+            PinMode::InputFloating => {
+              instance().disable_pullup(self.n);
+              instance().disable_output(self.n);
+            }
           }
-          mask <<= 1;
         }
-        instance().clear_interrupts();
+        #[inline(always)]
+        fn toggle(&mut self) {
+          instance().toggle(self.n);
+        }
+        #[inline(always)]
+        fn set_high(&mut self) {
+          instance().set_high(self.n);
+        }
+        #[inline(always)]
+        fn set_low(&mut self) {
+          instance().set_low(self.n);
+        }
+        #[inline(always)]
+        fn set(&mut self, high: bool) {
+          match high {
+            true  => instance().set_high(self.n),
+            false => instance().set_low(self.n)
+          }
+        }
+        #[inline(always)]
+        fn get(&self) -> bool {
+          instance().get(self.n)
+        }
+        fn set_interrupt_mode(&mut self, mode: InterruptMode) {
+          instance().set_interrupt_mode(self.n, mode)
+        }
+        fn listen(&mut self, handler: Option<PinInterruptHandler>){
+          crate::hal::concurrency::interrupt::isolated(||{
+            unsafe {
+              PINS[self.n as usize].handler = match handler {
+                Some(handler) => handler,
+                None => nop_handler
+              }
+            }
+          });
+        }
+      }
+
+      static mut INITIALISED: bool = false;
+
+      static mut INSTANCE : DummyPortRegisterBlock = DummyPortRegisterBlock {
+        pin: [false; 8],
+        o_en: [false; 8],
+        pu_en: [false; 8]
+      };
+
+      /**
+       * Get an instance of this port's register block.  Also does any
+       * static initialisation required of the device the first time it is
+       * called.
+       */
+      #[inline(always)]
+      pub fn instance() -> &'static mut DummyPortRegisterBlock  {
+        unsafe {
+          // Not sure if this is a compiler bug or what, but our static
+          // muts don't seem to be correctly initialised, so we need to
+          // do this here instead
+          //
+          // ( @todo investigate - Probably I need to amend my boot code to call
+          //         something to do the initialisation for me )
+          if(!INITIALISED){
+            for pin in 0..=7 {
+              PINS[pin].n = pin as u8;
+              PINS[pin].handler = nop_handler;
+            }
+            INITIALISED = true;
+          }
+
+          &mut INSTANCE
+        }
+      }
+
+      static mut PINS : [AtmelPin; 8] = [
+        AtmelPin { n: 0, handler: nop_handler },
+        AtmelPin { n: 1, handler: nop_handler },
+        AtmelPin { n: 2, handler: nop_handler },
+        AtmelPin { n: 3, handler: nop_handler },
+        AtmelPin { n: 4, handler: nop_handler },
+        AtmelPin { n: 5, handler: nop_handler },
+        AtmelPin { n: 6, handler: nop_handler },
+        AtmelPin { n: 7, handler: nop_handler },
+      ];
+
+
+      /**
+       * Return a single pin instance wrapper.
+       */
+      pub fn pin_instance(pin: u8) -> &'static mut AtmelPin {
+        debug_assert!(pin < 8);
+
+        unsafe {
+          PINS[0].handler = nop_handler;
+
+          &mut PINS[pin as usize]
+        }
       }
     }
   }
