@@ -58,6 +58,7 @@ pub trait TimerControl {
 
 
 // Code ======================================================================
+#[cfg(target_arch="avr")]
 pub mod base {
   use crate::hal::generic::timer::{TimerInterruptHandler, TimerMode, TimerControl};
 
@@ -239,10 +240,6 @@ pub mod base {
   #[macro_export]
   macro_rules! atmel_tcb {
     ($tcbref:expr, $isr:ident) => {
-
-
-      extern crate avr_device_snowgoons as avr_device;
-
       use crate::hal::generic::timer::TimerMode;
       use crate::hal::generic::timer::base::{ AtmelTimer, AtmelTCB, AvrTypeBTimerControl };
 
@@ -267,21 +264,188 @@ pub mod base {
       pub unsafe extern "avr-interrupt" fn $isr() {
         static mut COUNT_INTS : u16 = 0;
 
-        let counter = core::ptr::read_volatile(&COUNT_INTS as *const u16);
+        crate::hal::concurrency::interrupt::isr(||{
+          let counter = core::ptr::read_volatile(&COUNT_INTS as *const u16);
 
-        match &mut INSTANCE {
-          None => {},
-          Some(atmeltimer) => {
+          match &mut INSTANCE {
+            None => {},
+            Some(atmeltimer) => {
 
-            if counter == 0 {
-              atmeltimer.call_interrupt(COUNT_INTS.clone());
-              core::ptr::write_volatile(&mut COUNT_INTS as *mut u16, atmeltimer.interrupt_period())
-            } else {
-              core::ptr::write_volatile(&mut COUNT_INTS as *mut u16, counter-1);
+              if counter == 0 {
+                atmeltimer.call_interrupt(COUNT_INTS.clone());
+                core::ptr::write_volatile(&mut COUNT_INTS as *mut u16, atmeltimer.interrupt_period())
+              } else {
+                core::ptr::write_volatile(&mut COUNT_INTS as *mut u16, counter-1);
+              }
+
+              atmeltimer.tcb.clear_interrupt();
             }
-
-            atmeltimer.tcb.clear_interrupt();
           }
+        })
+      }
+    }
+  }
+}
+
+#[cfg(not(target_arch="avr"))]
+pub mod base {
+  use crate::hal::generic::timer::{TimerInterruptHandler, TimerMode, TimerControl};
+
+  #[repr(C)]
+  pub struct DummyTypeBTimerControl {
+  }
+
+  pub trait DummyTCB {
+    fn enable(&mut self);
+    fn disable(&mut self);
+    fn enable_interrupt(&mut self);
+    fn clear_interrupt(&mut self);
+    fn mask_interrupt(&mut self);
+    fn set_top(&mut self, top: u16);
+    fn set_periodic_mode(&mut self);
+  }
+
+  impl DummyTCB for DummyTypeBTimerControl {
+    fn enable(&mut self) {
+      println!("*** TCB: Enabled");
+    }
+
+    fn disable(&mut self) {
+      println!("*** TCB: Disabled");
+    }
+
+    fn enable_interrupt(&mut self) {
+      println!("*** TCB: Interrupts enabled");
+    }
+
+    fn clear_interrupt(&mut self) {
+      println!("*** TCB: Interrupts cleared");
+    }
+
+    fn mask_interrupt(&mut self) {
+      println!("*** TCB: Interrupts masked");
+    }
+
+    fn set_top(&mut self, top: u16) {
+      println!("*** TCB: Counter top set to {}", top);
+    }
+
+    #[inline(always)]
+    fn set_periodic_mode(&mut self) {
+      println!("*** TCB: Set to periodic mode");
+    }
+  }
+
+
+  #[allow(dead_code)]
+  pub struct DummyTimer<T>
+    where
+      T: 'static + DummyTCB
+  {
+    pub(crate) interrupt_handler: Option<TimerInterruptHandler>,
+    pub(crate) interrupt_period: u16,
+    pub(crate) tcb: T,
+    pub(crate) count_max: u16,
+    pub(crate) mode: TimerMode
+  }
+
+  impl<T> TimerControl for DummyTimer<T>
+    where
+      T: DummyTCB
+  {
+    fn interrupting(&mut self, period: u16) -> &mut Self {
+      println!("*** TCB: Set to interrupt every {} cycles", period);
+      self
+    }
+
+    fn mode(&mut self, _mode: TimerMode) -> &mut Self {
+      println!("*** TCB: Set timer mode");
+      self
+    }
+
+    fn count_max(&mut self, max: u16) -> &mut Self {
+      println!("*** TCB: Set count_max to {}", max);
+      self
+    }
+
+    fn start(&mut self, handler: Option<TimerInterruptHandler>) {
+      println!("*** TCB: Set handler to {:?}", handler);
+      self.tcb.disable();
+      match self.mode {
+        TimerMode::Periodic => {
+          self.tcb.set_periodic_mode();
+          self.tcb.set_top(self.count_max.clone());
+        }
+      };
+
+      self.tcb.clear_interrupt();
+      match handler {
+        None => {
+          self.tcb.mask_interrupt();
+        },
+        Some(handler) => {
+          self.interrupt_handler = Some(handler);
+          self.tcb.enable_interrupt();
+        }
+      }
+      self.tcb.enable();
+    }
+
+    fn stop(&mut self) {
+      self.tcb.disable();
+    }
+
+    fn get_count(&self) -> u16 {
+      todo!()
+    }
+
+    fn reset_count(&mut self) {
+      todo!()
+    }
+  }
+
+  impl<T> DummyTimer<T>
+    where
+      T: DummyTCB
+  {
+    #[allow(dead_code)]
+    pub(crate) fn call_interrupt(&mut self, ticks: u16) {
+      match self.interrupt_handler {
+        Some(handler) => {
+          match handler(ticks) {
+            true => {},
+            false => self.tcb.disable()
+          }
+        },
+        None => {}
+      }
+    }
+
+    #[allow(dead_code)]
+    pub(crate) fn interrupt_period(&self) -> u16 {
+      self.interrupt_period
+    }
+  }
+
+  #[macro_export]
+  macro_rules! atmel_tcb {
+    ($tcbref:expr, $isr:ident) => {
+      use crate::hal::generic::timer::TimerMode;
+      use crate::hal::generic::timer::base::{ DummyTimer, DummyTypeBTimerControl };
+
+      pub type TimerImpl = DummyTimer<DummyTypeBTimerControl>;
+
+      static mut INSTANCE: DummyTimer<DummyTypeBTimerControl> = DummyTimer {
+        interrupt_handler: None,
+        interrupt_period: 0,
+        tcb: DummyTypeBTimerControl {},
+        count_max: 0,
+        mode: TimerMode::Periodic
+      };
+
+      pub fn instance() -> &'static mut TimerImpl {
+        unsafe {
+          &mut INSTANCE
         }
       }
     }
