@@ -9,9 +9,10 @@
 //! sending events to the supervisor.
 
 // Imports ===================================================================
-use crate::ringq::RingQ;
+use crate::private::ringq::RingQ;
 use crate::event::{OxideEvent, EventSink};
 use crate::mut_singleton;
+use crate::hal::concurrency::interrupt;
 
 // Declarations ==============================================================
 
@@ -31,14 +32,13 @@ impl OxideSupervisor {
    * Enter the event loop - and never return (*evil cackle*)
    */
   pub fn run<F: FnMut(OxideEvent)>(&mut self, mut handler: F) -> ! {
-    unsafe {
-      crate::hal::concurrency::imp::enable_interrupts();
-    }
-
     loop {
-      crate::hal::concurrency::imp::wait_for_interrupt();
+      interrupt::wait();
 
-      while let Some(event) = self.event_q.consume() {
+      // We use the no-locking event Q.  This is safe as long as I am
+      // the only consumer, and any producers are running in an interrupt-secure
+      // context.
+      while let Some(event) = self.event_q.consume_nolock() {
         handler(event);
       }
     }
@@ -47,7 +47,14 @@ impl OxideSupervisor {
 
 impl EventSink for OxideSupervisor {
   fn event(event: OxideEvent) -> () {
-    instance().event_q.append(event).unwrap();
+    match instance().event_q.append_nolock(event) {
+      Ok(_) => {
+        // Do nothing
+      }
+      Err(_) => {
+        // Also do nothing...  If we can't add events, we will just discard
+      }
+    }
   }
 }
 
